%{!?upstream_version: %global upstream_version %{version}%{?milestone}}

# Python3 support in OpenStack starts with version 3.5,
# which is only in Fedora 24+
%if 0%{?fedora} >= 24
%global with_python3 1
%endif


%global library heat-translator
%global module translator
%global executable heat-translator

%global common_desc \
OpenStack Heat Translator \
Heat-Translator is an Openstack command line tool which takes non-Heat \
templates as an input and produces a Heat Orchestration Template (HOT) which \
can be deployed by Heat.

%global common_desc_tests OpenStack Heat Translator


Name:       python-%{library}
Version:    1.1.0
Release:    1%{?dist}
Summary:    OpenStack Heat Translator
License:    ASL 2.0
URL:        http://launchpad.net/%{library}/

Source0:    https://tarballs.openstack.org/%{library}/%{library}-%{upstream_version}.tar.gz

BuildArch:  noarch

BuildRequires:  python-devel
BuildRequires:  python-pbr
BuildRequires:  python-setuptools
BuildRequires:  git

# Test Requirements
BuildRequires:  python-hacking
BuildRequires:  python-fixtures
BuildRequires:  python-oslotest
BuildRequires:  python-subunit
BuildRequires:  python-requests
BuildRequires:  python-testrepository
BuildRequires:  python-testscenarios
BuildRequires:  python-testtools
BuildRequires:  python-tosca-parser
BuildRequires:  python-cliff

Requires:   python-pbr
Requires:   python-babel
Requires:   python-cliff
Requires:   PyYAML
Requires:   python-dateutil
Requires:   python-six
Requires:   python-tosca-parser
Requires:   python-keystoneauth1 >= 3.4.0
Requires:   python-novaclient >= 1:9.1.0
Requires:   python-heatclient >= 1.10.0
Requires:   python-glanceclient >= 1:2.8.0
Requires:   python-requests

%description 
%{common_desc}

%package -n python-%{library}-tests
Summary:    OpenStack example library tests
Requires:   python-%{library} = %{version}-%{release}
Requires:   python-hacking
Requires:   python-fixtures
Requires:   python-oslotest
Requires:   python-subunit
Requires:   python-testrepository
Requires:   python-testscenarios
Requires:   python-testtools
Requires:   python-tosca-parser

%description -n python-%{library}-tests
%{common_desc_tests}

This package contains the Heat Translator test files.

%package -n python-%{library}-doc
Summary:    OpenStack example library documentation

BuildRequires: python-sphinx
# FIXME(jpena): remove once a version including https://review.openstack.org/570889 is tagged
BuildRequires: python-oslo-sphinx
BuildRequires: python-openstackdocstheme

%description -n python-%{library}-doc
%{common_desc_tests}

This package contains the documentation.

%if 0%{?with_python3}
%package -n python3-%{library}
Summary:    OpenStack Heat Translator
%{?python_provide:%python_provide python3-%{library}}

BuildRequires:  python3-devel
BuildRequires:  python3-pbr
BuildRequires:  python3-setuptools

Requires:   python3-pbr
Requires:   python3-babel
Requires:   python3-cliff
Requires:   python3-PyYAML
Requires:   python3-dateutil
Requires:   python3-six
Requires:   python3-tosca-parser
Requires:   python3-keystoneauth1 >= 3.4.0
Requires:   python3-novaclient >= 1:9.1.0
Requires:   python3-heatclient >= 1.10.0
Requires:   python3-glanceclient >= 1:2.8.0
Requires:   python3-requests

%description -n python3-%{library}
%{common_desc}

%package -n python3-%{library}-tests
Summary:    OpenStack Heat Translator tests
Requires:   python3-%{library} = %{version}-%{release}
Requires:   python3-hacking
Requires:   python3-fixtures
Requires:   python3-oslotest
Requires:   python3-subunit
Requires:   python3-testrepository
Requires:   python3-testscenarios
Requires:   python3-testtools
Requires:   python3-tosca-parser

%description -n python3-%{library}-tests
%{common_desc_tests}

This package contains the Heat Translator test files.

%endif # with_python3


%prep
%autosetup -n %{library}-%{upstream_version} -S git

# Let's handle dependencies ourseleves
rm -f *requirements.txt

%build
%py2_build
%if 0%{?with_python3}
%py3_build
%endif

# generate html docs
sphinx-build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%if 0%{?with_python3}
%py3_install
mv %{buildroot}%{_bindir}/%{executable} %{buildroot}%{_bindir}/%{executable}-%{python3_version}
ln -s ./%{executable}-%{python3_version} %{buildroot}%{_bindir}/%{executable}-3
%endif

%py2_install
mv %{buildroot}%{_bindir}/%{executable} %{buildroot}%{_bindir}/%{executable}-%{python_version}
ln -s ./%{executable}-%{python_version} %{buildroot}%{_bindir}/%{executable}-2

ln -s ./%{executable}-2 %{buildroot}%{_bindir}/%{executable}

# Looks like Unit tests depend on sockets
# need to mock out sockets upstream
# running %check non-fatally for now
%check
%if 0%{?with_python3}
%{__python3} setup.py test ||:
rm -rf .testrepository
%endif
%{__python} setup.py test ||:

%files 
%license LICENSE
%{python_sitelib}/%{module}
%{python_sitelib}/heat_%{module}-*.egg-info
%exclude %{python_sitelib}/%{module}/tests
%{_bindir}/%{executable}
%{_bindir}/%{executable}-2
%{_bindir}/%{executable}-%{python_version}

%files -n python-%{library}-tests
%license LICENSE
%{python_sitelib}/%{module}/tests

%files -n python-%{library}-doc
%license LICENSE
%doc doc/build/html README.rst

%if 0%{?with_python3}
%files -n python3-%{library}
%license LICENSE
%{python3_sitelib}/%{module}
%{python3_sitelib}/heat_%{module}-*.egg-info
%exclude %{python3_sitelib}/%{module}/tests
%{_bindir}/%{executable}-3
%{_bindir}/%{executable}-%{python3_version}

%files -n python3-%{library}-tests
%license LICENSE
%{python3_sitelib}/%{module}/tests
%endif # with_python3

%changelog
* Mon Aug 20 2018 RDO <dev@lists.rdoproject.org> 1.1.0-1
- Update to 1.1.0

